.. DessiaCommon documentation master file, created by
   sphinx-quickstart on Thu Feb 20 15:37:42 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to DessiaCommon's documentation!
========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started
   subclassing
   customizing
   core
   datatools
   workflow
   advanced



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
